%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

%if 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%if 0%{?rhel} > 7
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
# Golang minor version
%define gominver 16
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 70fb67b4a453c436c06d4ec299a76855a35ee6ab
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.22.5
Release: 9.rhaos4.9.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
Patch0: gpgme-pthread.patch
%if 0%{?rhel} && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: make
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.%{gominver} -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --storage-driver "overlay" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --storage-opt "overlay.override_kernel_check=1" \
      --metrics-port 9537 \
      --enable-metrics \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf
make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json
install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Thu Aug 11 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.5-9.rhaos4.9.git70fb67b
- autobuilt 70fb67b

* Tue Jul 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.5-8.rhaos4.9.gite5b6040
- autobuilt e5b6040

* Mon Jun 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.5-7.rhaos4.9.git3dbcd3c
- autobuilt 3dbcd3c

* Wed Jun 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.5-6.rhaos4.9.gitc972b0a
- autobuilt c972b0a

* Thu Jun 16 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.5-5.rhaos4.9.gitbd7ea64
- autobuilt bd7ea64

* Thu Jun 16 2022 Peter Hunt <pehunt@redhat.com> - 1.22.5-4.rhaos4.9.gitb6d3a87
- remove cve patch

* Sun Jun 05 2022 Peter Hunt <pehunt@redhat.com> - 1.22.5-3.rhaos4.9.gitb6d3a87
- update patch to handle conmon version

* Sun Jun 05 2022 Peter Hunt <pehunt@redhat.com> - 1.22.5-2.rhaos4.9.gitb6d3a87
- update patch

* Fri Jun 03 2022 Peter Hunt <pehunt@redhat.com> - 1.22.5-1.rhaos4.9.gitb6d3a87
- bump to v1.22.5

* Thu Jun 02 2022 Peter Hunt <pehunt@redhat.com> - 1.22.4-4.rhaos4.9.gitb6d3a87
- add cve-2022-1822.patch

* Thu May 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.4-3.rhaos4.9.gitb6d3a87
- autobuilt b6d3a87

* Tue May 17 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.4-2.rhaos4.9.gite060681
- bump to 1.22.4
- autobuilt e060681

* Wed May 11 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-8.rhaos4.9.git6cb2fb1
- autobuilt 6cb2fb1

* Tue May 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-7.rhaos4.9.git1cc1233
- autobuilt 1cc1233

* Wed May 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-6.rhaos4.9.git388405c
- autobuilt 388405c

* Wed Apr 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-5.rhaos4.9.git7cf77a9
- autobuilt 7cf77a9

* Tue Apr 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-4.rhaos4.9.gitc46200f
- autobuilt c46200f

* Wed Apr 06 2022 Peter Hunt <pehunt@redhat.com> - 1.22.3-3.rhaos4.9.git28c5a70
- add gpgme-pthread patch

* Mon Mar 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.3-2.rhaos4.9.git28c5a70
- bump to 1.22.3
- autobuilt 28c5a70

* Mon Mar 21 2022 Peter Hunt <pehunt@redhat.com> - 1.22.2-4.rhaos4.9.gitb030be8
- revert sysctl patch

* Thu Mar 10 2022 Peter Hunt <pehunt@redhat.com> - 1.22.2-3.rhaos4.9.gitb030be8
- add sysctl patch for CVE-2022-0811

* Thu Feb 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.2-2.rhaos4.9.gitb030be8
- bump to 1.22.2
- autobuilt b030be8

* Tue Feb 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-21.rhaos4.9.git74a7981
- autobuilt 74a7981

* Fri Feb 18 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-20.rhaos4.9.gitb53b319
- autobuilt b53b319

* Thu Feb 17 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-19.rhaos4.9.git6487091
- autobuilt 6487091

* Thu Feb 17 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-18.rhaos4.9.gitab89fa1
- autobuilt ab89fa1

* Tue Feb 15 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-17.rhaos4.9.git3029b1d
- autobuilt 3029b1d

* Thu Feb 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-16.rhaos4.9.git12fa1c7
- autobuilt 12fa1c7

* Thu Feb 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-15.rhaos4.9.git3c9732a
- autobuilt 3c9732a

* Tue Feb 08 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-14.rhaos4.9.git7486bc8
- autobuilt 7486bc8

* Mon Jan 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-13.rhaos4.9.git9746add
- autobuilt 9746add

* Wed Jan 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-12.rhaos4.9.gitac40287
- autobuilt ac40287

* Tue Jan 18 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-11.rhaos4.9.git936ed81
- autobuilt 936ed81

* Thu Dec 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-10.rhaos4.9.gitf1d2c6e
- autobuilt f1d2c6e

* Tue Dec 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-9.rhaos4.9.gitaeeadca
- autobuilt aeeadca

* Fri Dec 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-8.rhaos4.9.gite059965
- autobuilt e059965

* Mon Nov 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-7.rhaos4.9.git8ed8e79
- autobuilt 8ed8e79

* Sat Nov 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-6.rhaos4.9.git7ade1b0
- bump to 1.22.1
- autobuilt 7ade1b0

* Wed Nov 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-5.rhaos4.9.git7ade1b0
- autobuilt 7ade1b0

* Thu Nov 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-4.rhaos4.9.gite3dfe61
- autobuilt e3dfe61

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-3.rhaos4.9.git861ff3a
- autobuilt 861ff3a

* Mon Nov 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.1-2.rhaos4.9.git63ca938
- bump to 1.22.1
- autobuilt 63ca938

* Tue Nov 02 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-91.rhaos4.9.gitd745cab
- bump

* Tue Nov 02 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-90.rhaos4.9.gitd745cab
- fix version

* Tue Nov 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.gitd745cab
- bump to 1.22.0
- autobuilt d745cab

* Tue Nov 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Tue Nov 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.gitd745cab
- bump to 1.22.0
- autobuilt d745cab

* Tue Nov 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Thu Oct 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-89.rhaos4.9.gitd745cab
- autobuilt d745cab

* Wed Sep 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-88.rhaos4.9.gitbdf286c
- autobuilt bdf286c

* Wed Sep 22 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-87.rhaos4.9.gitfeb4cbe
- autobuilt feb4cbe

* Tue Sep 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-86.rhaos4.9.gitd54f8e1
- autobuilt d54f8e1

* Mon Sep 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-85.rhaos4.9.git7a3c55d
- autobuilt 7a3c55d

* Fri Sep 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-84.rhaos4.9.git148b8c9
- autobuilt 148b8c9

* Mon Aug 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-83.rhaos4.9.git011c10a
- autobuilt 011c10a

* Thu Aug 26 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-82.rhaos4.9.git6becad2
- drop unneeded files

* Wed Aug 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-81.rhaos4.9.git6becad2
- autobuilt 6becad2

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-80.rhaos4.9.git5d5a754
- autobuilt 5d5a754

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-79.rhaos4.9.git3682514
- autobuilt 3682514

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-78.rhaos4.9.git1d44719
- autobuilt 1d44719

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-77.rhaos4.9.git690c533
- autobuilt 690c533

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-76.rhaos4.9.gitcf0a31c
- autobuilt cf0a31c

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-75.rhaos4.9.git10db266
- autobuilt 10db266

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-74.rhaos4.9.gite3ee92e
- autobuilt e3ee92e

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-73.rhaos4.9.git4e5a828
- autobuilt 4e5a828

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-72.rhaos4.9.git411113d
- autobuilt 411113d

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-71.rhaos4.9.git9f38eee
- autobuilt 9f38eee

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-70.rhaos4.9.git177ed5f
- autobuilt 177ed5f

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-69.rhaos4.9.git8234f90
- autobuilt 8234f90

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-68.rhaos4.9.git2d289a2
- autobuilt 2d289a2

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-67.rhaos4.9.git1520733
- autobuilt 1520733

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-66.rhaos4.9.gitf05d651
- autobuilt f05d651

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-65.rhaos4.9.gitd8af189
- autobuilt d8af189

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-64.rhaos4.9.git1536782
- autobuilt 1536782

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-63.rhaos4.9.gitabbfb13
- autobuilt abbfb13

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-62.rhaos4.9.gita6ed448
- autobuilt a6ed448

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-61.rhaos4.9.git359c7f8
- autobuilt 359c7f8

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-60.rhaos4.9.git3a523e9
- autobuilt 3a523e9

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-59.rhaos4.9.gitc1e95b1
- autobuilt c1e95b1

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-58.rhaos4.9.git56fb46e
- autobuilt 56fb46e

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-57.rhaos4.9.gitdf41b98
- autobuilt df41b98

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-56.rhaos4.9.git71ab700
- autobuilt 71ab700

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-55.rhaos4.9.git8bcf6f7
- autobuilt 8bcf6f7

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-54.rhaos4.9.git71ec863
- autobuilt 71ec863

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-53.rhaos4.9.git94060e3
- autobuilt 94060e3

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-52.rhaos4.9.gitfe3d631
- autobuilt fe3d631

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-51.rhaos4.9.git7cc1f62
- autobuilt 7cc1f62

* Mon Aug 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-50.rhaos4.9.gitc53e78f
- autobuilt c53e78f

* Wed Aug 11 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-49.rhaos4.9.git78f06f2
- use conmon from path

* Tue Aug 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-48.rhaos4.9.git78f06f2
- autobuilt 78f06f2

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-47.rhaos4.9.gita07f02f
- autobuilt a07f02f

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-46.rhaos4.9.giteb3cca9
- autobuilt eb3cca9

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-45.rhaos4.9.git779df95
- autobuilt 779df95

* Sun Aug 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-44.rhaos4.9.git6092081
- autobuilt 6092081

* Fri Aug 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-43.rhaos4.9.git126b893
- autobuilt 126b893

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-42.rhaos4.9.git2c92506
- autobuilt 2c92506

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-41.rhaos4.9.git226e658
- autobuilt 226e658

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-40.rhaos4.9.gitcc72388
- autobuilt cc72388

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-39.rhaos4.9.git8d4df4e
- autobuilt 8d4df4e

* Tue Aug 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-38.rhaos4.9.gita414fed
- autobuilt a414fed

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-37.rhaos4.9.git79a25c4
- autobuilt 79a25c4

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-36.rhaos4.9.gitee8e721
- autobuilt ee8e721

* Fri Jul 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-35.rhaos4.9.git1b8b9e4
- autobuilt 1b8b9e4

* Thu Jul 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-34.rhaos4.9.git6ac8cee
- autobuilt 6ac8cee

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-33.rhaos4.9.git13e698f
- autobuilt 13e698f

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-32.rhaos4.9.gitb6d6cde
- autobuilt b6d6cde

* Tue Jul 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-31.rhaos4.9.git5ab85f5
- autobuilt 5ab85f5

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-30.rhaos4.9.gita212a95
- autobuilt a212a95

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-29.rhaos4.9.git4fa3dd3
- autobuilt 4fa3dd3

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-28.rhaos4.9.git49a8247
- autobuilt 49a8247

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-27.rhaos4.9.git0fc6d47
- autobuilt 0fc6d47

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-26.rhaos4.9.git0f8266d
- autobuilt 0f8266d

* Wed Jul 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-25.rhaos4.9.gite06cce2
- autobuilt e06cce2

* Tue Jul 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-24.rhaos4.9.gitaf2035b
- autobuilt af2035b

* Mon Jul 19 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-23.rhaos4.9.git1cf63c7
- sunset support for custom rpm crio.service file

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.git1cf63c7
- autobuilt 1cf63c7

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-21.rhaos4.9.git635b2d9
- autobuilt 635b2d9

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-20.rhaos4.9.gite00180d
- autobuilt e00180d

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab9.rhaos4.9.gitc969a38
- autobuilt c969a38

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab8.rhaos4.9.gitcd1c5a0
- autobuilt cd1c5a0

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab7.rhaos4.9.git1309dd2
- autobuilt 1309dd2

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab6.rhaos4.9.git4d14fd6
- autobuilt 4d14fd6

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab5.rhaos4.9.gitde5e0fe
- autobuilt de5e0fe

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab4.rhaos4.9.gitf2dcf32
- autobuilt f2dcf32

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab3.rhaos4.9.gitacd0f73
- autobuilt acd0f73

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab2.rhaos4.9.gitb123b0c
- autobuilt b123b0c

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab1.rhaos4.9.gitab3a2f4
- autobuilt ab3a2f4

* Tue Jul 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab0.rhaos4.9.git196e779
- autobuilt 196e779

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-9.rhaos4.9.giteffa584
- autobuilt effa584

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-8.rhaos4.9.git472b3ae
- autobuilt 472b3ae

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.gitfeb7a4c
- autobuilt feb7a4c

* Wed Jul 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.9.git3e5a1e4
- autobuilt 3e5a1e4

* Mon Jul 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.9.gitc8b82d6
- autobuilt c8b82d6

* Sat Jul 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.9.gitd41627b
- autobuilt d41627b

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.9.git0aa5724
- autobuilt 0aa5724

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.git2b8e727
- bump to 1.22.0
- autobuilt 2b8e727

* Wed Jun 30 2021 Peter Hunt <pehunt@redhat.com> - 1.21.0-5.rhaos4.9.git741bd7c
- rebuild for golang fips fix

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-4.rhaos4.9.git741bd7c
- autobuilt 741bd7c

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-3.rhaos4.9.git6664604
- autobuilt 6664604

* Tue Jun 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-2.rhaos4.9.git9dd6f42
- bump to 1.21.0
- autobuilt 9dd6f42

* Tue Jun 29 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-1.rhaos4.9.gitd745cab.rhaos4.9.gitd745cab.rhaos4.9.git2b8e727.rhaos4.9.gitcd7f051
- Initial build of 1.22
